@@ -4,9 +4,12 @@ from __future__ import annotations
 
 import uuid
 from dataclasses import dataclass, field
-from datetime import datetime
+from datetime import UTC, datetime
 from enum import Enum
-from typing import Any, Dict, List, Optional, Set
+from typing import TYPE_CHECKING, Any, Dict, List, Optional, Set
+
+if TYPE_CHECKING:
+    from .storage import LackeyStorage
 
 from .notes import Note, NoteManager, NoteType
 
@@ -15,7 +18,7 @@ class TaskStatus(Enum):
     """Task status enumeration."""
 
     TODO = "todo"
-    IN_PROGRESS = "in-progress"
+    IN_PROGRESS = "in_progress"
     BLOCKED = "blocked"
     DONE = "done"
 
@@ -83,7 +86,7 @@ class Task:
         dependencies: Optional[Set[str]] = None,
     ) -> Task:
         """Create a new task with generated ID and timestamps."""
-        now = datetime.utcnow()
+        now = datetime.now(UTC)
 
         return cls(
             id=str(uuid.uuid4()),
@@ -105,7 +108,7 @@ class Task:
         """Update task status and timestamp with history tracking."""
         old_status = self.status
         self.status = new_status
-        self.updated = datetime.utcnow()
+        self.updated = datetime.now(UTC)
 
         # Track status change in history
         if old_status != new_status:
@@ -121,12 +124,12 @@ class Task:
     def add_dependency(self, task_id: str) -> None:
         """Add a dependency to this task."""
         self.dependencies.add(task_id)
-        self.updated = datetime.utcnow()
+        self.updated = datetime.now(UTC)
 
     def remove_dependency(self, task_id: str) -> None:
         """Remove a dependency from this task."""
         self.dependencies.discard(task_id)
-        self.updated = datetime.utcnow()
+        self.updated = datetime.now(UTC)
 
     def add_note(
         self,
@@ -144,7 +147,7 @@ class Task:
             tags=tags,
             metadata=metadata,
         )
-        self.updated = datetime.utcnow()
+        self.updated = datetime.now(UTC)
         return note
 
     def add_simple_note(self, note: str) -> Note:
@@ -157,13 +160,13 @@ class Task:
             if step_index not in self.completed_steps:
                 self.completed_steps.append(step_index)
                 self.completed_steps.sort()
-                self.updated = datetime.utcnow()
+                self.updated = datetime.now(UTC)
 
     def uncomplete_step(self, step_index: int) -> None:
         """Mark a step as incomplete."""
         if step_index in self.completed_steps:
             self.completed_steps.remove(step_index)
-            self.updated = datetime.utcnow()
+            self.updated = datetime.now(UTC)
 
     def is_ready(self, completed_tasks: Set[str]) -> bool:
         """Check if task is ready to start (all dependencies completed)."""
@@ -289,7 +292,7 @@ class Project:
             friendly_name=friendly_name,
             description=description,
             status=ProjectStatus.ACTIVE,
-            created=datetime.utcnow(),
+            created=datetime.now(UTC),
             objectives=objectives,
             tags=tags or [],
             metadata=metadata or {},
@@ -298,31 +301,31 @@ class Project:
     def update_status(self, new_status: ProjectStatus) -> None:
         """Update project status."""
         self.status = new_status
-        self.metadata["last_modified"] = datetime.utcnow().isoformat()
+        self.metadata["last_modified"] = datetime.now(UTC).isoformat()
 
     def add_objective(self, objective: str) -> None:
         """Add an objective to the project."""
         if objective not in self.objectives:
             self.objectives.append(objective)
-            self.metadata["last_modified"] = datetime.utcnow().isoformat()
+            self.metadata["last_modified"] = datetime.now(UTC).isoformat()
 
     def remove_objective(self, objective: str) -> None:
         """Remove an objective from the project."""
         if objective in self.objectives:
             self.objectives.remove(objective)
-            self.metadata["last_modified"] = datetime.utcnow().isoformat()
+            self.metadata["last_modified"] = datetime.now(UTC).isoformat()
 
     def add_tag(self, tag: str) -> None:
         """Add a tag to the project."""
         if tag not in self.tags:
             self.tags.append(tag)
-            self.metadata["last_modified"] = datetime.utcnow().isoformat()
+            self.metadata["last_modified"] = datetime.now(UTC).isoformat()
 
     def remove_tag(self, tag: str) -> None:
         """Remove a tag from the project."""
         if tag in self.tags:
             self.tags.remove(tag)
-            self.metadata["last_modified"] = datetime.utcnow().isoformat()
+            self.metadata["last_modified"] = datetime.now(UTC).isoformat()
 
     def to_dict(self) -> Dict[str, Any]:
         """Convert project to dictionary for serialization."""
@@ -363,7 +366,15 @@ class ProjectIndex:
     """
 
     version: str = "1.0"
-    projects: List[Dict[str, Any]] = field(default_factory=list)
+    projects: List[Dict[str, Any]] = field(
+        default_factory=list
+    )  # Project metadata and counts
+    task_to_project: Dict[str, str] = field(
+        default_factory=dict
+    )  # task_id -> project_id
+    task_to_file: Dict[str, str] = field(
+        default_factory=dict
+    )  # task_id -> relative_path
 
     def add_project(
         self, project: Project, task_count: int = 0, completed_count: int = 0
@@ -386,6 +397,47 @@ class ProjectIndex:
     def remove_project(self, project_id: str) -> None:
         """Remove a project from the index."""
         self.projects = [p for p in self.projects if p["id"] != project_id]
+        # Remove all tasks for this project
+        tasks_to_remove = [
+            task_id
+            for task_id, pid in self.task_to_project.items()
+            if pid == project_id
+        ]
+        for task_id in tasks_to_remove:
+            self.task_to_project.pop(task_id, None)
+            self.task_to_file.pop(task_id, None)
+
+    def add_task_mapping(
+        self, task_id: str, project_id: str, relative_path: str
+    ) -> None:
+        """Add task-to-project and task-to-file mappings."""
+        self.task_to_project[task_id] = project_id
+        self.task_to_file[task_id] = relative_path
+
+    def remove_task_mapping(self, task_id: str) -> None:
+        """Remove task mappings."""
+        self.task_to_project.pop(task_id, None)
+        self.task_to_file.pop(task_id, None)
+
+    def get_task_project(self, task_id: str) -> str | None:
+        """Get project ID for a task."""
+        return self.task_to_project.get(task_id)
+
+    def get_task_file(self, task_id: str) -> str | None:
+        """Get relative file path for a task."""
+        return self.task_to_file.get(task_id)
+
+    def rebuild_from_filesystem(self, storage: "LackeyStorage") -> None:
+        """Rebuild task mappings from filesystem when index is stale."""
+        self.task_to_project.clear()
+        self.task_to_file.clear()
+
+        for project_dict in storage.list_projects():
+            project_id = project_dict["id"]
+            tasks = storage.list_project_tasks(project_id)
+            for task in tasks:
+                relative_path = f"projects/{project_id}/tasks/{task.id}.md"
+                self.add_task_mapping(task.id, project_id, relative_path)
 
     def get_project_entry(self, project_id: str) -> Optional[Dict[str, Any]]:
         """Get project entry by ID."""
@@ -429,7 +481,7 @@ class LackeyConfig:
     """
 
     version: str = "1.0"
-    created: datetime = field(default_factory=datetime.utcnow)
+    created: datetime = field(default_factory=lambda: datetime.now(UTC))
     workspace: Dict[str, Any] = field(
         default_factory=lambda: {
             "auto_validate_dag": True,
@@ -477,7 +529,7 @@ class LackeyConfig:
             created=(
                 datetime.fromisoformat(data["created"])
                 if "created" in data
-                else datetime.utcnow()
+                else datetime.now(UTC)
             ),
             workspace=data.get("workspace", {}),
             ai_agents=data.get("ai_agents", {}),
