@@ -1,5 +1,6 @@
 """File-based storage system for Lackey tasks and projects."""
 
+import logging
 import re
 from pathlib import Path
 from typing import Any, Dict, List, Optional, Tuple
@@ -14,6 +15,8 @@ from .file_ops import (
 )
 from .models import LackeyConfig, Project, ProjectIndex, Task, TaskStatus
 
+logger = logging.getLogger(__name__)
+
 
 class StorageError(Exception):
     """Raised when storage operations fail."""
@@ -41,10 +44,14 @@ class LackeyStorage:
     for tasks, projects, and configuration data.
     """
 
-    def __init__(self, workspace_path: str = "."):
-        """Initialize storage with workspace path."""
-        self.workspace_path = Path(workspace_path).resolve()
-        self.lackey_dir = self.workspace_path / ".lackey"
+    def __init__(self, lackey_dir_path: str = ".lackey"):
+        """Initialize storage with Lackey directory path.
+
+        Args:
+            lackey_dir_path: Path to the .lackey directory where files are stored
+        """
+        self.lackey_dir = Path(lackey_dir_path).resolve()
+        self.workspace_path = self.lackey_dir.parent
         self.projects_dir = self.lackey_dir / "projects"
         self.index_file = self.lackey_dir / "index.yaml"
         self.config_file = self.lackey_dir / "config.yaml"
@@ -192,25 +199,58 @@ class LackeyStorage:
             # Update project task counts
             self._update_project_task_counts(project_id)
 
+            # Add task mapping to index
+            index = self._get_project_index()
+            relative_path = f"projects/{project_id}/tasks/{task.id}.md"
+            index.add_task_mapping(task.id, project_id, relative_path)
+            self._save_project_index(index)
+
         except FileOperationError as e:
             raise StorageError(f"Failed to create task: {e}")
 
-    def get_task(self, project_id: str, task_id: str) -> Task:
-        """Get task by ID from specified project."""
-        project_dir = self.projects_dir / project_id
-        task_file = project_dir / "tasks" / f"{task_id}.md"
+    def get_task(self, task_id: str) -> Task:
+        """Get task by ID from any project."""
+        for project_dir in self.projects_dir.iterdir():
+            if not project_dir.is_dir():
+                continue
 
-        if not task_file.exists():
-            raise TaskNotFoundError(f"Task {task_id} not found in project {project_id}")
+            task_file = project_dir / "tasks" / f"{task_id}.md"
+            if task_file.exists():
+                try:
+                    content = read_text_file(str(task_file))
+                    return self._markdown_to_task(content)
+                except FileOperationError:
+                    continue
 
-        try:
-            content = read_text_file(str(task_file))
-            return self._markdown_to_task(content)
-        except FileOperationError as e:
-            raise StorageError(f"Failed to read task: {e}")
+        raise TaskNotFoundError(f"Task {task_id} not found")
 
-    def update_task(self, project_id: str, task: Task) -> None:
+    def find_project_id_by_task_id(self, task_id: str) -> str:
+        """Find which project contains the given task ID."""
+        for project_dir in self.projects_dir.iterdir():
+            if not project_dir.is_dir():
+                continue
+
+            task_file = project_dir / "tasks" / f"{task_id}.md"
+            if task_file.exists():
+                return project_dir.name
+
+        raise TaskNotFoundError(f"Task {task_id} not found in any project")
+
+    def update_task(self, task: Task) -> None:
         """Update existing task."""
+        # Get project from index
+        index = self._get_project_index()
+        project_id = index.get_task_project(task.id)
+
+        # Rebuild index if task not found
+        if not project_id:
+            index.rebuild_from_filesystem(self)
+            self._save_project_index(index)
+            project_id = index.get_task_project(task.id)
+
+        if not project_id:
+            raise TaskNotFoundError(f"Task {task.id} not found")
+
         project_dir = self.projects_dir / project_id
         task_file = project_dir / "tasks" / f"{task.id}.md"
 
@@ -229,13 +269,29 @@ class LackeyStorage:
         except FileOperationError as e:
             raise StorageError(f"Failed to update task: {e}")
 
-    def delete_task(self, project_id: str, task_id: str) -> None:
-        """Delete task from project."""
-        project_dir = self.projects_dir / project_id
-        task_file = project_dir / "tasks" / f"{task_id}.md"
+    def delete_task(self, task_id: str) -> None:
+        """Delete task."""
+        # Get project and file path from index
+        index = self._get_project_index()
+        project_id = index.get_task_project(task_id)
+
+        # Rebuild index if task not found
+        if not project_id:
+            index.rebuild_from_filesystem(self)
+            self._save_project_index(index)
+            project_id = index.get_task_project(task_id)
+
+        if not project_id:
+            raise TaskNotFoundError(f"Task {task_id} not found")
+
+        task_file_path = index.get_task_file(task_id)
+        if not task_file_path:
+            raise TaskNotFoundError(f"Task {task_id} file path not found")
+
+        task_file = self.lackey_dir / task_file_path
 
         if not task_file.exists():
-            raise TaskNotFoundError(f"Task {task_id} not found in project {project_id}")
+            raise TaskNotFoundError(f"Task {task_id} file not found")
 
         try:
             # Create backup before deletion
@@ -244,6 +300,10 @@ class LackeyStorage:
             # Update project task counts
             self._update_project_task_counts(project_id)
 
+            # Remove task mapping from index
+            index.remove_task_mapping(task_id)
+            self._save_project_index(index)
+
         except FileOperationError as e:
             raise StorageError(f"Failed to delete task: {e}")
 
@@ -272,6 +332,22 @@ class LackeyStorage:
         except FileOperationError as e:
             raise StorageError(f"Failed to list tasks: {e}")
 
+    def list_tasks(self, status_filter: Optional[TaskStatus] = None) -> List[Task]:
+        """List all tasks across all projects with optional status filter."""
+        try:
+            index = self._get_project_index()
+            all_tasks = []
+
+            for project_entry in index.projects:
+                project_id = project_entry["id"]
+                tasks = self.list_project_tasks(project_id, status_filter)
+                all_tasks.extend(tasks)
+
+            return all_tasks
+
+        except FileOperationError as e:
+            raise StorageError(f"Failed to list all tasks: {e}")
+
     def search_tasks(
         self, query: str, project_id: Optional[str] = None
     ) -> List[Tuple[str, Task]]:
@@ -279,6 +355,8 @@ class LackeyStorage:
         results = []
         query_lower = query.lower()
 
+        logger.info(f"Storage search_tasks: query='{query}', project_id={project_id}")
+
         try:
             # Determine which projects to search
             if project_id:
@@ -314,7 +392,13 @@ class LackeyStorage:
                             ]
                         ).lower()
 
+                        logger.info(
+                            f"Task '{task.title}' searchable text: "
+                            f"'{searchable_text[:100]}...'"
+                        )
+
                         if query_lower in searchable_text:
+                            logger.info(f"Match found in task: {task.title}")
                             results.append((proj_dir.name, task))
 
                     except FileOperationError:
@@ -672,7 +756,7 @@ class LackeyStorage:
             if line.startswith("### Note "):
                 # Parse the header
                 import re
-                from datetime import datetime
+                from datetime import UTC, datetime
 
                 # Pattern: ### Note {id} ({type}) - {timestamp}[ by {author}][ #{tags}]
                 pattern = (
@@ -690,7 +774,7 @@ class LackeyStorage:
                             timestamp_str.strip(), "%Y-%m-%d %H:%M:%S.%f"
                         )
                     except ValueError:
-                        created = datetime.utcnow()
+                        created = datetime.now(UTC)
 
                     # Parse tags
                     tags = []
