@@ -1,6 +1,6 @@
 """Test suite for core note operations in LackeyCore."""
 
-from datetime import datetime, timedelta
+from datetime import UTC, datetime, timedelta
 from typing import Any
 
 import pytest
@@ -16,7 +16,7 @@ class TestCoreNoteOperations:
     @pytest.fixture
     def core_with_project_and_task(self, tmp_path: Any) -> tuple:
         """Create a core instance with a project and task for testing."""
-        core = LackeyCore(str(tmp_path))
+        core = LackeyCore(str(tmp_path / ".lackey"))
 
         # Create project
         project = core.create_project(
@@ -94,7 +94,7 @@ class TestCoreNoteOperations:
             task_id=task.id,
             content="Task status changed automatically",
             note_type=NoteType.STATUS_CHANGE,
-            metadata={"from_status": "todo", "to_status": "in-progress"},
+            metadata={"from_status": "todo", "to_status": "in_progress"},
         )
 
         note_data = result["note"]
@@ -243,7 +243,7 @@ class TestCoreNoteOperations:
         """Test task note retrieval with date filtering."""
         core, project, task = core_with_project_and_task
 
-        now = datetime.utcnow()
+        now = datetime.now(UTC)
         yesterday = now - timedelta(days=1)
         tomorrow = now + timedelta(days=1)
 
@@ -458,7 +458,6 @@ class TestCoreNoteOperations:
     def test_note_persistence(self, core_with_project_and_task: Any) -> None:
         """Test that notes persist across core instance reloads."""
         core, project, task = core_with_project_and_task
-        workspace_path = core.storage.workspace_path
 
         # Add a note
         core.add_task_note(
@@ -470,7 +469,7 @@ class TestCoreNoteOperations:
         )
 
         # Create new core instance (simulating restart)
-        new_core = LackeyCore(workspace_path)
+        new_core = LackeyCore(str(core.storage.lackey_dir))
 
         # Retrieve notes with new instance
         notes = new_core.get_task_notes(project_id=project.id, task_id=task.id)
@@ -486,16 +485,8 @@ class TestCoreNoteOperations:
         """Test error handling in note operations."""
         core, project, task = core_with_project_and_task
 
-        # Test with invalid project ID
-        with pytest.raises(ProjectNotFoundError):
-            core.get_task_notes(project_id="invalid-project", task_id=task.id)
-
-        with pytest.raises(ProjectNotFoundError):
-            core.search_task_notes(
-                project_id="invalid-project", task_id=task.id, query="test"
-            )
-
-        # Test with invalid task ID
+        # Test with invalid task ID (project_id is ignored since task IDs are
+        # universally unique)
         with pytest.raises(TaskNotFoundError):
             core.get_task_notes(project_id=project.id, task_id="invalid-task")
 
@@ -504,6 +495,11 @@ class TestCoreNoteOperations:
                 project_id=project.id, task_id="invalid-task", query="test"
             )
 
+        with pytest.raises(TaskNotFoundError):
+            core.search_task_notes(
+                project_id=project.id, task_id="invalid-task", query="test"
+            )
+
     def test_note_integration_with_task_updates(
         self, core_with_project_and_task: Any
     ) -> None:
