@@ -1,6 +1,6 @@
 """Tests for core task operations API."""
 
-from typing import Any, Tuple
+from typing import Any
 from unittest.mock import Mock, patch
 
 import pytest
@@ -15,7 +15,7 @@ class TestTaskStatusOperations:
     """Test task status update operations."""
 
     def test_update_task_status_valid_transition(
-        self, core_with_project_and_tasks: Tuple[LackeyCore, Project, list[Task]]
+        self, core_with_project_and_tasks: tuple[LackeyCore, Project, list[Task]]
     ) -> None:
         """Test updating task status with valid transition."""
         core, project, tasks = core_with_project_and_tasks
@@ -33,7 +33,7 @@ class TestTaskStatusOperations:
         assert updated_task.updated >= original_updated
 
     def test_update_task_status_with_note(
-        self, core_with_project_and_tasks: Tuple[LackeyCore, Project, list[Task]]
+        self, core_with_project_and_tasks: tuple[LackeyCore, Project, list[Task]]
     ) -> None:
         """Test updating task status with a note."""
         core, project, tasks = core_with_project_and_tasks
@@ -52,7 +52,7 @@ class TestTaskStatusOperations:
         assert "Started working on this task" in notes[0].content
 
     def test_update_task_status_invalid_task(
-        self, core_with_project: Tuple[LackeyCore, Project]
+        self, core_with_project: tuple[LackeyCore, Project]
     ) -> None:
         """Test updating status of non-existent task."""
         core, project = core_with_project
@@ -63,7 +63,7 @@ class TestTaskStatusOperations:
             )
 
     def test_bulk_update_task_status(
-        self, core_with_project_and_tasks: Tuple[LackeyCore, Project, list[Task]]
+        self, core_with_project_and_tasks: tuple[LackeyCore, Project, list[Task]]
     ) -> None:
         """Test bulk status updates."""
         core, project, tasks = core_with_project_and_tasks
@@ -78,7 +78,7 @@ class TestTaskStatusOperations:
 
         # Verify tasks were updated
         for task_id in task_ids:
-            updated_task = core.get_task(project.id, task_id)
+            updated_task = core.get_task(task_id)
             assert updated_task.status == TaskStatus.IN_PROGRESS
 
 
@@ -86,7 +86,7 @@ class TestStepCompletionOperations:
     """Test step completion tracking operations."""
 
     def test_complete_task_steps(
-        self, core_with_project_and_tasks: Tuple[LackeyCore, Project, list[Task]]
+        self, core_with_project_and_tasks: tuple[LackeyCore, Project, list[Task]]
     ) -> None:
         """Test completing multiple task steps."""
         core, project, tasks = core_with_project_and_tasks
@@ -101,7 +101,7 @@ class TestStepCompletionOperations:
         assert len(updated_task.note_manager.get_notes()) == 1
 
     def test_uncomplete_task_steps(
-        self, core_with_project_and_tasks: Tuple[LackeyCore, Project, list[Task]]
+        self, core_with_project_and_tasks: tuple[LackeyCore, Project, list[Task]]
     ) -> None:
         """Test uncompleting task steps."""
         core, project, tasks = core_with_project_and_tasks
@@ -120,7 +120,7 @@ class TestStepCompletionOperations:
         assert 2 in updated_task.completed_steps
 
     def test_get_task_progress_summary(
-        self, core_with_project_and_tasks: Tuple[LackeyCore, Project, list[Task]]
+        self, core_with_project_and_tasks: tuple[LackeyCore, Project, list[Task]]
     ) -> None:
         """Test getting task progress summary."""
         core, project, tasks = core_with_project_and_tasks
@@ -137,7 +137,7 @@ class TestStepCompletionOperations:
         assert progress["remaining_steps"] == len(task.steps) - 2
 
     def test_auto_status_update_on_completion(
-        self, core_with_project_and_tasks: Tuple[LackeyCore, Project, list[Task]]
+        self, core_with_project_and_tasks: tuple[LackeyCore, Project, list[Task]]
     ) -> None:
         """Test automatic status update when all steps completed."""
         core, project, tasks = core_with_project_and_tasks
@@ -157,7 +157,7 @@ class TestTaskAssignmentOperations:
     """Test task assignment and reassignment operations."""
 
     def test_assign_task(
-        self, core_with_project_and_tasks: Tuple[LackeyCore, Project, list[Task]]
+        self, core_with_project_and_tasks: tuple[LackeyCore, Project, list[Task]]
     ) -> None:
         """Test assigning a task to someone."""
         core, project, tasks = core_with_project_and_tasks
@@ -174,7 +174,7 @@ class TestTaskAssignmentOperations:
         assert len(updated_task.note_manager.get_notes()) == 1
 
     def test_reassign_task(
-        self, core_with_project_and_tasks: Tuple[LackeyCore, Project, list[Task]]
+        self, core_with_project_and_tasks: tuple[LackeyCore, Project, list[Task]]
     ) -> None:
         """Test reassigning a task."""
         core, project, tasks = core_with_project_and_tasks
@@ -195,7 +195,7 @@ class TestTaskAssignmentOperations:
         assert len(updated_task.note_manager.get_notes()) == 2
 
     def test_unassign_task(
-        self, core_with_project_and_tasks: Tuple[LackeyCore, Project, list[Task]]
+        self, core_with_project_and_tasks: tuple[LackeyCore, Project, list[Task]]
     ) -> None:
         """Test unassigning a task."""
         core, project, tasks = core_with_project_and_tasks
@@ -213,7 +213,7 @@ class TestTaskAssignmentOperations:
         assert len(updated_task.note_manager.get_notes()) == 2
 
     def test_bulk_assign_tasks(
-        self, core_with_project_and_tasks: Tuple[LackeyCore, Project, list[Task]]
+        self, core_with_project_and_tasks: tuple[LackeyCore, Project, list[Task]]
     ) -> None:
         """Test bulk task assignment."""
         core, project, tasks = core_with_project_and_tasks
@@ -226,7 +226,7 @@ class TestTaskAssignmentOperations:
 
         # Verify assignments
         for task_id in task_ids:
-            updated_task = core.get_task(project.id, task_id)
+            updated_task = core.get_task(task_id)
             assert updated_task.assigned_to == "developer"
 
 
@@ -234,7 +234,7 @@ class TestDependencyManagementOperations:
     """Test dynamic dependency management operations."""
 
     def test_add_multiple_dependencies(
-        self, core_with_project_and_tasks: Tuple[LackeyCore, Project, list[Task]]
+        self, core_with_project_and_tasks: tuple[LackeyCore, Project, list[Task]]
     ) -> None:
         """Test adding multiple dependencies at once."""
         core, project, tasks = core_with_project_and_tasks
@@ -249,7 +249,7 @@ class TestDependencyManagementOperations:
         assert tasks[2].id in updated_task.dependencies
 
     def test_remove_multiple_dependencies(
-        self, core_with_project_and_tasks: Tuple[LackeyCore, Project, list[Task]]
+        self, core_with_project_and_tasks: tuple[LackeyCore, Project, list[Task]]
     ) -> None:
         """Test removing multiple dependencies at once."""
         core, project, tasks = core_with_project_and_tasks
@@ -268,7 +268,7 @@ class TestDependencyManagementOperations:
         assert tasks[2].id not in updated_task.dependencies
 
     def test_replace_task_dependencies(
-        self, core_with_project_and_tasks: Tuple[LackeyCore, Project, list[Task]]
+        self, core_with_project_and_tasks: tuple[LackeyCore, Project, list[Task]]
     ) -> None:
         """Test replacing all task dependencies."""
         core, project, tasks = core_with_project_and_tasks
@@ -289,7 +289,7 @@ class TestDependencyManagementOperations:
         assert tasks[3].id in updated_task.dependencies
 
     def test_dependency_cycle_prevention(
-        self, core_with_project_and_tasks: Tuple[LackeyCore, Project, list[Task]]
+        self, core_with_project_and_tasks: tuple[LackeyCore, Project, list[Task]]
     ) -> None:
         """Test that dependency cycles are prevented."""
         core, project, tasks = core_with_project_and_tasks
@@ -307,7 +307,7 @@ class TestAdvancedTaskOperations:
     """Test advanced task operations."""
 
     def test_clone_task(
-        self, core_with_project_and_tasks: Tuple[LackeyCore, Project, list[Task]]
+        self, core_with_project_and_tasks: tuple[LackeyCore, Project, list[Task]]
     ) -> None:
         """Test cloning a task."""
         core, project, tasks = core_with_project_and_tasks
@@ -328,7 +328,7 @@ class TestAdvancedTaskOperations:
         assert len(cloned_task.dependencies) == 0  # copy_dependencies=False
 
     def test_clone_task_with_dependencies(
-        self, core_with_project_and_tasks: Tuple[LackeyCore, Project, list[Task]]
+        self, core_with_project_and_tasks: tuple[LackeyCore, Project, list[Task]]
     ) -> None:
         """Test cloning a task with dependencies."""
         core, project, tasks = core_with_project_and_tasks
@@ -347,42 +347,38 @@ class TestAdvancedTaskOperations:
         assert tasks[1].id in cloned_task.dependencies
 
     def test_archive_task(
-        self, core_with_project_and_tasks: Tuple[LackeyCore, Project, list[Task]]
+        self, core_with_project_and_tasks: tuple[LackeyCore, Project, list[Task]]
     ) -> None:
         """Test archiving a task."""
         core, project, tasks = core_with_project_and_tasks
         task = tasks[0]
 
-        archived_task = core.archive_task(
-            project.id, task.id, reason="No longer needed"
-        )
+        archived_task = core.archive_task(task.id, reason="No longer needed")
 
-        assert "archived" in archived_task.tags
         assert len(archived_task.note_manager.get_notes()) == 1
         assert "No longer needed" in archived_task.note_manager.get_notes()[0].content
 
     def test_restore_task(
-        self, core_with_project_and_tasks: Tuple[LackeyCore, Project, list[Task]]
+        self, core_with_project_and_tasks: tuple[LackeyCore, Project, list[Task]]
     ) -> None:
         """Test restoring an archived task."""
         core, project, tasks = core_with_project_and_tasks
         task = tasks[0]
 
         # First archive
-        core.archive_task(project.id, task.id, reason="Test archive")
+        core.archive_task(task.id, reason="Test archive")
 
         # Then restore
         restored_task = core.restore_task(
             project.id, task.id, note="Restored for continued work"
         )
 
-        assert "archived" not in restored_task.tags
         assert (
             len(restored_task.note_manager.get_notes()) == 2
         )  # Archive + restore notes
 
     def test_split_task(
-        self, core_with_project_and_tasks: Tuple[LackeyCore, Project, list[Task]]
+        self, core_with_project_and_tasks: tuple[LackeyCore, Project, list[Task]]
     ) -> None:
         """Test splitting a task into subtasks."""
         core, project, tasks = core_with_project_and_tasks
@@ -413,7 +409,7 @@ class TestAdvancedTaskOperations:
 
         # Verify subtasks were created
         for subtask_id in result["subtask_ids"]:
-            subtask = core.get_task(project.id, subtask_id)
+            subtask = core.get_task(subtask_id)
             assert subtask.complexity == original_task.complexity
             assert subtask.assigned_to == original_task.assigned_to
 
@@ -422,7 +418,7 @@ class TestTaskValidationOperations:
     """Test task validation operations."""
 
     def test_validate_task_data(
-        self, core_with_project: Tuple[LackeyCore, Project]
+        self, core_with_project: tuple[LackeyCore, Project]
     ) -> None:
         """Test task data validation."""
         core, project = core_with_project
@@ -441,7 +437,7 @@ class TestTaskValidationOperations:
         assert len(validation_result["errors"]) == 0
 
     def test_validate_task_data_invalid(
-        self, core_with_project: Tuple[LackeyCore, Project]
+        self, core_with_project: tuple[LackeyCore, Project]
     ) -> None:
         """Test task data validation with invalid data."""
         core, project = core_with_project
@@ -460,7 +456,7 @@ class TestTaskValidationOperations:
         assert len(validation_result["errors"]) > 0
 
     def test_validate_task_dependencies_integrity(
-        self, core_with_project_and_tasks: Tuple[LackeyCore, Project, list[Task]]
+        self, core_with_project_and_tasks: tuple[LackeyCore, Project, list[Task]]
     ) -> None:
         """Test validating task dependency integrity."""
         core, project, tasks = core_with_project_and_tasks
@@ -480,7 +476,7 @@ class TestBulkTaskOperations:
     """Test bulk task operations."""
 
     def test_bulk_delete_tasks(
-        self, core_with_project_and_tasks: Tuple[LackeyCore, Project, list[Task]]
+        self, core_with_project_and_tasks: tuple[LackeyCore, Project, list[Task]]
     ) -> None:
         """Test bulk task deletion."""
         core, project, tasks = core_with_project_and_tasks
@@ -494,10 +490,10 @@ class TestBulkTaskOperations:
         # Verify tasks were deleted
         for task_id in task_ids:
             with pytest.raises(TaskNotFoundError):
-                core.get_task(project.id, task_id)
+                core.get_task(task_id)
 
     def test_bulk_update_task_properties(
-        self, core_with_project_and_tasks: Tuple[LackeyCore, Project, list[Task]]
+        self, core_with_project_and_tasks: tuple[LackeyCore, Project, list[Task]]
     ) -> None:
         """Test bulk updating task properties."""
         core, project, tasks = core_with_project_and_tasks
@@ -512,17 +508,24 @@ class TestBulkTaskOperations:
 
         # Verify updates
         for task_id in task_ids:
-            updated_task = core.get_task(project.id, task_id)
+            updated_task = core.get_task(task_id)
             assert updated_task.complexity == Complexity.HIGH
             assert "urgent" in updated_task.tags
             assert "priority" in updated_task.tags
 
 
-@pytest.fixture  # type: ignore[misc]
-def core_with_project() -> Tuple[LackeyCore, Project]:
+@pytest.fixture
+def core_with_project() -> tuple[LackeyCore, Project]:
     """Fixture providing core with a test project."""
     # Create a mock storage instance
     mock_storage = Mock()
+    mock_storage.get_task = Mock()
+    mock_storage.update_task = Mock()
+    mock_storage.create_task = Mock()
+    mock_storage.delete_task = Mock()
+    mock_storage.list_project_tasks = Mock()
+    mock_storage.list_projects = Mock()
+    mock_storage.find_project_id_by_task_id = Mock()
 
     # Mock project
     from lackey.models import Project
@@ -534,7 +537,7 @@ def core_with_project() -> Tuple[LackeyCore, Project]:
     )
 
     # Mock get_task to raise TaskNotFoundError for invalid task IDs
-    def mock_get_task(project_id: str, task_id: str) -> Task:
+    def mock_get_task(task_id: str) -> Task:
         raise TaskNotFoundError(f"Task {task_id} not found")
 
     mock_storage.get_project.return_value = project
@@ -550,10 +553,10 @@ def core_with_project() -> Tuple[LackeyCore, Project]:
         return core, project
 
 
-@pytest.fixture  # type: ignore[misc]
+@pytest.fixture
 def core_with_project_and_tasks(
-    core_with_project: Tuple[LackeyCore, Project]
-) -> Tuple[LackeyCore, Project, list[Task]]:
+    core_with_project: tuple[LackeyCore, Project]
+) -> tuple[LackeyCore, Project, list[Task]]:
     """Fixture providing core with project and test tasks."""
     core, project = core_with_project
 
@@ -574,13 +577,13 @@ def core_with_project_and_tasks(
         tasks.append(task)
 
     # Mock storage methods
-    def mock_get_task(project_id: str, task_id: str) -> Task:
+    def mock_get_task(task_id: str) -> Task:
         for task in tasks:
             if task.id == task_id:
                 return task
         raise TaskNotFoundError(f"Task {task_id} not found")
 
-    def mock_update_task(project_id: str, task: Task) -> Task:
+    def mock_update_task(task: Task) -> Task:
         # Find and update the task in our list
         for i, existing_task in enumerate(tasks):
             if existing_task.id == task.id:
@@ -592,7 +595,7 @@ def core_with_project_and_tasks(
         tasks.append(task)
         return task
 
-    def mock_delete_task(project_id: str, task_id: str) -> None:
+    def mock_delete_task(task_id: str) -> None:
         for i, task in enumerate(tasks):
             if task.id == task_id:
                 del tasks[i]
@@ -606,18 +609,22 @@ def core_with_project_and_tasks(
         return tasks.copy()
 
     # Configure mock methods
-    core.storage.get_task.side_effect = mock_get_task  # type: ignore[attr-defined]
-    core.storage.update_task.side_effect = (  # type: ignore[attr-defined]
-        mock_update_task
-    )
-    core.storage.create_task.side_effect = (  # type: ignore[attr-defined]
-        mock_create_task
-    )
-    core.storage.delete_task.side_effect = (  # type: ignore[attr-defined]
-        mock_delete_task
-    )
-    core.storage.list_project_tasks.side_effect = (  # type: ignore[attr-defined]
-        mock_list_project_tasks
+    core.storage.get_task.side_effect = mock_get_task
+    core.storage.update_task.side_effect = mock_update_task
+    core.storage.create_task.side_effect = mock_create_task
+    core.storage.delete_task.side_effect = mock_delete_task
+    core.storage.list_project_tasks.side_effect = mock_list_project_tasks
+
+    # Add missing mocks for delete_task method
+    def mock_list_projects() -> list[dict]:
+        return [{"id": project.id, "name": project.name}]
+
+    def mock_find_project_id_by_task_id(task_id: str) -> str:
+        return str(project.id)
+
+    core.storage.list_projects.side_effect = mock_list_projects
+    core.storage.find_project_id_by_task_id.side_effect = (
+        mock_find_project_id_by_task_id
     )
 
     return core, project, tasks
